JIRA CLI
========

JIRA CLI is a command line interface for JIRA that attempts to make common JIRA tasks easier.

Usage
-----

.. code-block:: shell

    >>> jira-term


Install
-------

Install Lassie via `pip <http://www.pip-installer.org/>`_

.. code-block:: bash

    $ pip install jira-term

or, with `easy_install <http://pypi.python.org/pypi/setuptools>`_

.. code-block:: bash

    $ easy_install jira-term

But, hey... `that's up to you <http://www.pip-installer.org/en/latest/other-tools.html#pip-compared-to-easy-install>`_.

Documentation
-------------

TBA
